#### Summary R script using a time series composed by two example of Landsat images (XX and YY)

# List of the libriry and functions used in this study

library(rgdal)
# readOGR()
library(raster)
# mask(); crop(); brick(); stack() plotRGB(); raster(); rasterToPolygons()
# union(); buffer(); rasterize(); rasterFromXYZ()
library(RStoolbox)
# readMeta()
library(insol)
# normalvector(); doshade()
library(rgeos)
# gUnion()
library (fclust)
# FKM()
library(reshape)
# melt()
library(ggplot2)
# ggplot()
library(vegan)
# metaMDS(); ordiplot(); stressplot(); ordisurf()
library(indicspecies)
# multipatt()
library(dplyr)
# inner_join()
library(cowplot)
# plot_grid()

####################### STEP 1
####################### Time series of satellite images

#### Landsat time series 
#### Selection of images minimizing clouds and snow cover


# Import imageries of the 30 years time series (XX and YY). The study area is centered in the Adamello glacier
# and it has a radius of 10 km.

area<-readOGR("C:/path/...", "study_area")

allBandsXX<-list.files("C:/path/.../", pattern="...", full.names=TRUE)
dnXX<-mask(crop(brick(stack(allBands[c(1:5,7)])), area), area)
names(dnXX)<-gsub(pattern="...", replace="b", x= names(dnXX))
metaXX<-readMeta("C:/path/.../..._MTL.txt")

allBandsYY<-list.files("C:/path/.../", pattern="...", full.names=TRUE)
dnYY<-mask(crop(brick(stack(allBands[c(1:5,7)])), area), area)
names(dnYY)<-gsub(pattern="...", replace="b", x= names(dnYY))
metaYY<-readMeta("C:/path/.../..._MTL.txt")

# Plot the imageries
plotRGB(dnXX, r=3, g=2, b=1,  stretch = "lin", axes = TRUE, main = sprintf("Natural color: %s", substr(metaXX$ACQUISITION_DATE, 0, 10)))
plotRGB(dnYY, r=3, g=2, b=1,  stretch = "lin", axes = TRUE, main = sprintf("Natural color: %s", substr(metaYY$ACQUISITION_DATE, 0, 10)))

#### Mask
#### Clouds, topographical and clouds shadows, 60 m buffer area

# Calculate the shaded area using a DEM and the information on the sun position in each of the imagery.
dem<-crop(raster("C:/path/.../Dem.tif"), area)

svXX<-normalvector(metaXX$SOLAR_PARAMETERS[2], metaXX$SOLAR_PARAMETERS[1])
shadeXX<-doshade(dem, sv=svXX)
shade_polXX<-rasterToPolygons(shade, fun=function(x){x==0}, dissolve=TRUE)

svYY<-normalvector(metaYY$SOLAR_PARAMETERS[2], metaYY$SOLAR_PARAMETERS[1])
shadeYY<-doshade(dem, sv=svYY)
shade_polYY<-rasterToPolygons(shade, fun=function(x){x==0}, dissolve=TRUE)

tot.shade<-gUnion(shade_polXX, shade_polYY)

# Importing clouds casts, their shadows and unreliable pixels due to defective funcioning of the satellite 
# from QGIS. I used the Fmask function with 0.25 as probability treshold
# and 0 pixels as the buffer for both the clouds and their shadows. The buffer area will be calculated later using
# the complete mask (i.e. topographically shaded area, clouds and their shadows)

maskXX<-crop(raster("C:/path/.../Fmask_XX.tif"), area)
maskYY<-crop(raster("C:/path/.../Fmask_XX.tif"), area)
stripes<-crop(readOGR("C:/path/.../", "stripe"), area)

mask.tot<-union(stripes, maskXX)
mask.tot<-union(mask.tot, maskYY)
mask.tot<-union(mask.tot, shade_polXX)
mask.tot<-union(mask.tot, shade_polYY)

mask.tot<-aggregate(crop(mask.tot, area))

plotRGB(dnXX, r=4, g=3, b=2, stretch="lin", axes=TRUE, margins=TRUE)
plot(mask.tot, add=TRUE, col="yellow", border="yellow")

# Now I add the buffer (60 m, two landsat cells) to the complete mask.

mask.buffer<-buffer(mask.tot, width=60)
mask.buffer.rast <- rasterize(mask.buffer, dnXX[[1]])
mask.buffer.rast[mask.buffer.rast>1]<-1
mask.buffer.pol<-rasterToPolygons(mask.buffer.rast, fun=function(x){x==1}, dissolve=TRUE)

# At the end, the area that I am going to exclude from the anlyses is the 32.7% of the total.

(area(mask.buffer.pol)/area(area))*100

# Apply the mask to all the imageries. I have to use raster to mask, otherwies I lose holes.

dnXX.mask<-mask(dnXX, mask.buffer.rast, inverse=TRUE)
dnYY.mask<-mask(dnYY, mask.buffer.rast, inverse=TRUE)

#### Satellite based indices
#### NDVI, NDSI, NDWI, MDNWI

b2<-raster(dnXX.mask, layer=2)
b3<-raster(dnXX.mask, layer=3)
b4<-raster(dnXX.mask, layer=4)
b5<-raster(dnXX.mask, layer=5)

ndviXX<-(b4-b3)/(b4+b3)
ndwiXX<-(b2-b4)/(b2+b4)
ndsiXX<-(b5-b4)/(b5+b4)
mndwiXX<-(b2-b5)/(b2+b5)

b2<-raster(dnYY.mask, layer=2)
b3<-raster(dnYY.mask, layer=3)
b4<-raster(dnYY.mask, layer=4)
b5<-raster(dnYY.mask, layer=5)

ndviYY<-(b4-b3)/(b4+b3)
ndwiYY<-(b2-b4)/(b2+b4)
ndsiYY<-(b5-b4)/(b5+b4)
mndwiYY<-(b2-b5)/(b2+b5)

index<-c(ndviXX, ndwiXX, ndsiXX, mndwiXX)
indexXX<-brick(stack(index))
names(indexXX)<-c("ndvi", "ndwi", "ndsi", "mndwi")
df.indXX<-as.data.frame(indexXX, na.rm=TRUE, xy=TRUE)

index<-c(ndviYY, ndwiYY, ndsiYY, mndwiYY)
indexYY<-brick(stack(index))
names(indexYY)<-c("ndvi", "ndwi", "ndsi", "mndwi")
df.indYY<-as.data.frame(indexYY, na.rm=TRUE, xy=TRUE)

####################### STEP 2
####################### Partitioning of the spectral space

#### Fuzzy K-means 
#### Unsupervised clustering of each time window

start_time=Sys.time()
start_time
fuzzy.indXX.3<-FKM(df.indXX[,3:6], k=3, RS=1, seed=18)
end_time=Sys.time()
end_time

start_time=Sys.time()
start_time
fuzzy.indXX.6<-FKM(df.indXX[,3:6], k=6, RS=1, seed=18)
end_time=Sys.time()
end_time

start_time=Sys.time()
start_time
fuzzy.indXX.7<-FKM(df.indXX[,3:6], k=7, RS=1, seed=18)
end_time=Sys.time()
end_time

df.fuzzy.indXX.3<-data.frame(df.indXX$x, df.indXX$y, as.data.frame(fuzzy.indXX.3$U))
names(df.fuzzy.indXX.3)<-c("x", "y", "fz1", "fz2", "fz3")
ras.fz.indXX.3<-rasterFromXYZ(df.fuzzy.indXX.3, res=c(30, 30), crs=dnXX.mask@crs)

df.fuzzy.indXX.6<-data.frame(df.indXX$x, df.indXX$y, as.data.frame(fuzzy.indXX.6$U))
names(df.fuzzy.indXX.6)<-c("x", "y", "fz1", "fz2", "fz3", "fz4", "fz5", "fz6")
ras.fz.indXX.6<-rasterFromXYZ(df.fuzzy.indXX.6, res=c(30, 30), crs=dnXX.mask@crs)

df.fuzzy.indXX.7<-data.frame(df.indXX$x, df.indXX$y, as.data.frame(fuzzy.indXX.7$U))
names(df.fuzzy.indXX.7)<-c("x", "y", "fz1", "fz2", "fz3", "fz4", "fz5", "fz6", "fz7")
ras.fz.indXX.7<-rasterFromXYZ(df.fuzzy.indXX.7, res=c(30, 30), crs=dnXX.mask@crs)


start_time=Sys.time()
start_time
fuzzy.indYY.3<-FKM(df.indYY[,3:6], k=3, RS=1, seed=18)
end_time=Sys.time()
end_time

start_time=Sys.time()
start_time
fuzzy.indYY.6<-FKM(df.indYY[,3:6], k=6, RS=1, seed=18)
end_time=Sys.time()
end_time

start_time=Sys.time()
start_time
fuzzy.indYY.7<-FKM(df.indYY[,3:6], k=7, RS=1, seed=18)
end_time=Sys.time()
end_time

df.fuzzy.indYY.3<-data.frame(df.indYY$x, df.indYY$y, as.data.frame(fuzzy.indYY.3$U))
names(df.fuzzy.indYY.3)<-c("x", "y", "fz1", "fz2", "fz3")
ras.fz.indYY.3<-rasterFromXYZ(df.fuzzy.indYY.3, res=c(30, 30), crs=dnYY.mask@crs)

df.fuzzy.indYY.6<-data.frame(df.indYY$x, df.indYY$y, as.data.frame(fuzzy.indYY.6$U))
names(df.fuzzy.indYY.6)<-c("x", "y", "fz1", "fz2", "fz3", "fz4", "fz5", "fz6")
ras.fz.indYY.6<-rasterFromXYZ(df.fuzzy.indYY.6, res=c(30, 30), crs=dnYY.mask@crs)

df.fuzzy.indYY.7<-data.frame(df.indYY$x, df.indYY$y, as.data.frame(fuzzy.indYY.7$U))
names(df.fuzzy.indYY.7)<-c("x", "y", "fz1", "fz2", "fz3", "fz4", "fz5", "fz6", "fz7")
ras.fz.indYY.7<-rasterFromXYZ(df.fuzzy.indYY.7, res=c(30, 30), crs=dnYY.mask@crs)

####################### STEP 3
####################### A posteriori definition of land-cover types

##### Comparison of centroids
##### Consistency among images of centroid values

centersXX.3<-data.frame(t(fuzzy.indXX.3$H), row.names(t(fuzzy.indXX.3$H)))
names(centersXX.3)<-c("c1","c2","c3", "index")
centersXX.3.m <- melt(centersXX.3, id.vars='index')
graphXX.3<-ggplot(centersXX.3.m, aes(variable, value)) + 
  geom_bar(aes(fill = index), stat = "identity", position = "dodge")
str(fuzzy.indXX.6)

centersXX.6<-data.frame(t(fuzzy.indXX.6$H), row.names(t(fuzzy.indXX.6$H)))
names(centersXX.6)<-c("c1","c2","c3","c4", "c5", "c6", "index")
centersXX.6.m <- melt(centersXX.6, id.vars='index')
graphXX.6<-ggplot(centersXX.6.m, aes(variable, value)) + 
  geom_bar(aes(fill = index), stat = "identity", position = "dodge")

centersXX.7<-data.frame(t(fuzzy.indXX.7$H), row.names(t(fuzzy.indXX.7$H)))
names(centersXX.7)<-c("c1","c2","c3","c4", "c5", "c6", "c7", "index")
centersXX.7.m <- melt(centersXX.7, id.vars='index')
graphXX.7<-ggplot(centersXX.7.m, aes(variable, value)) + 
  geom_bar(aes(fill = index), stat = "identity", position = "dodge")

centersYY.3<-data.frame(t(fuzzy.indYY.3$H), row.names(t(fuzzy.indYY.3$H)))
names(centersYY.3)<-c("c1","c2","c3", "index")
centersYY.3.m <- melt(centersYY.3, id.vars='index')
graphYY.3<-ggplot(centersYY.3.m, aes(variable, value)) + 
  geom_bar(aes(fill = index), stat = "identity", position = "dodge")
str(fuzzy.indYY.6)

centersYY.6<-data.frame(t(fuzzy.indYY.6$H), row.names(t(fuzzy.indYY.6$H)))
names(centersYY.6)<-c("c1","c2","c3","c4", "c5", "c6", "index")
centersYY.6.m <- melt(centersYY.6, id.vars='index')
graphYY.6<-ggplot(centersYY.6.m, aes(variable, value)) + 
  geom_bar(aes(fill = index), stat = "identity", position = "dodge")

centersYY.7<-data.frame(t(fuzzy.indYY.7$H), row.names(t(fuzzy.indYY.7$H)))
names(centersYY.7)<-c("c1","c2","c3","c4", "c5", "c6", "c7", "index")
centersYY.7.m <- melt(centersYY.7, id.vars='index')
graphYY.7<-ggplot(centersYY.7.m, aes(variable, value)) + 
  geom_bar(aes(fill = index), stat = "identity", position = "dodge")

##### Comparison of distribution
##### Consistency among images of membership values distribution

plot(ras.fz.indXX.3[[1]])
plot(ras.fz.indYY.3[[1]])
plot(ras.fz.indXX.3[[2]])
plot(ras.fz.indYY.3[[2]])
plot(ras.fz.indXX.3[[3]])
plot(ras.fz.indYY.3[[3]])

plot(ras.fz.indXX.6[[1]])
plot(ras.fz.indYY.6[[1]])
plot(ras.fz.indXX.6[[2]])
plot(ras.fz.indYY.6[[2]])
plot(ras.fz.indXX.6[[3]])
plot(ras.fz.indYY.6[[3]])
plot(ras.fz.indXX.6[[4]])
plot(ras.fz.indYY.6[[4]])
plot(ras.fz.indXX.6[[5]])
plot(ras.fz.indYY.6[[5]])
plot(ras.fz.indXX.6[[6]])
plot(ras.fz.indYY.6[[6]])

plot(ras.fz.indXX.7[[1]])
plot(ras.fz.indYY.7[[1]])
plot(ras.fz.indXX.7[[2]])
plot(ras.fz.indYY.7[[2]])
plot(ras.fz.indXX.7[[3]])
plot(ras.fz.indYY.7[[3]])
plot(ras.fz.indXX.7[[4]])
plot(ras.fz.indYY.7[[4]])
plot(ras.fz.indXX.7[[5]])
plot(ras.fz.indYY.7[[5]])
plot(ras.fz.indXX.7[[6]])
plot(ras.fz.indYY.7[[6]])
plot(ras.fz.indXX.7[[7]])
plot(ras.fz.indYY.7[[7]])


c Comparison of distribution
##### Consistency among images of composition in terms of entities obtained from 
##### very high-resolution images

# the datsets have for each row this information
# Class (Forest, LA grassland, UP grassland, Glacier, Water bodies, Unclassified)
# Cover (percentage cover of entities visually assessed)
# Entities (trees, shrubs, herbs, unvegetated ground, ice, water, altitude)

# data formatted for boxplot with altitude
check1<-read.delim("C:/path/.../check1.txt", header=T, row.names=1)
check2<-read.delim("C:/path/.../check2.txt", header=T, row.names=1)

check1$Entities <- factor(check1$Entities, levels = c("Trees", "Shrubs", "Herbs",
"Unvegetated ground", "Ice", "Water", "Altitude"))

check1.bp <- ggplot(check1, aes(x=Class, y=Cover, fill=Entities)) + 
  geom_boxplot()+theme_bw()+
  scale_x_discrete(limits=c("Forest","LA grassland", "UA grassland", "Subnival", "Glacier", "Water", "Unclassified"))+
  scale_fill_manual(values=c("green4", "green2", "yellow3", "grey69", "cyan", "blue1", "white"))+
  scale_y_continuous(sec.axis = sec_axis(name = "Altitude [m a.s.l.]"))+
  ylab("Cover [%]")+xlab("Land-Cover types")

check2$Entities <- factor(check2$Entities, levels = c("Trees", "Shrubs", "Herbs",
"Unvegetated ground", "Ice", "Water", "Altitude"))

check2.bp <- ggplot(check2, aes(x=Class, y=Cover, fill=Entities)) + 
  geom_boxplot()+theme_bw()+
  scale_x_discrete(limits=c("Forest","LA grassland", "UA grassland", "Subnival", "Glacier", "Water", "Unclassified"))+
  scale_fill_manual(values=c("green4", "green2", "yellow3", "grey69", "cyan", "blue1", "white"))+
  scale_y_continuous(sec.axis = sec_axis(name = "Altitude [m a.s.l.]"))+
  ylab("Cover [%]")+xlab("Land-Cover types")

entities_graph<-grid.arrange(check1.bp, check2.bp)


####################### STEP 4
####################### A posteriori definition of vegetation belts

# A samples X species matrix and header data are loaded.
# Samples are ordered followinf their land-cover assignment

spe<-read.delim("C:/path/.../spe.txt", header=T, row.names=1)
dat<-read.delim("C:/path/.../dat.txt", header=T, row.names=1)

#### Analysis of similarities
#### Test of taxonomical differences among vegetation belts 
#### using Bray-Crutis dissimilarity

anosim(spe, dat$Crisp.Map.2016, permutations=999,distance="bray") NMDS

#### NMDS
#### Ordination of plots to visualize vegetation belts along
#### the elevational gradient in a multivariate space

set.seed(1234)
NMDS <- metaMDS (log1p(spe))
NMDS

par (mfrow = c(1,2))
ordiplot (NMDS, cex = 1.5, type = 't', display="site")
stressplot (NMDS)

par (mfrow = c(1,2))
ordiplot (NMDS, type = 'n')
for (i in seq (1, 4)) ordispider (NMDS, groups = dat$gr,
	show.groups = i, col = i, label = T)
ordisurf (NMDS, dat[, 'Altitude'], main = 'Altitude')

ordiplot (NMDS, display="species", type="text")

# Dominant species: species with a cover > "cov.tresh" 
# for more than the "freq.tresh" percentage of samples

cov.tresh<-35
freq.tresh<-5

spe.t1<-as.data.frame(t(spe.bb[1:20,]))
spe.fre1<-spe.t1
spe.fre1[spe.fre1>0]<-1
spe.t2<-as.data.frame(t(spe.bb[21:40,]))
spe.fre2<-spe.t2
spe.fre2[spe.fre2>0]<-1
spe.t3<-as.data.frame(t(spe.bb[41:60,]))
spe.fre3<-spe.t3
spe.fre3[spe.fre3>0]<-1
spe.t4<-as.data.frame(t(spe.bb[61:80,]))
spe.fre4<-spe.t4
spe.fre4[spe.fre4>0]<-1

spe.dom1<-as.data.frame(t(spe[1:20,]))
spe.dom1[spe.dom1<=cov.tresh]<-0
spe.dom1[spe.dom1>cov.tresh]<-1

spe.dom2<-as.data.frame(t(spe[21:40,]))
spe.dom2[spe.dom2<=cov.tresh]<-0
spe.dom2[spe.dom2>cov.tresh]<-1

spe.dom3<-as.data.frame(t(spe[41:60,]))
spe.dom3[spe.dom3<=cov.tresh]<-0
spe.dom3[spe.dom3>cov.tresh]<-1

spe.dom4<-as.data.frame(t(spe[61:80,]))
spe.dom4[spe.dom4<=cov.tresh]<-0
spe.dom4[spe.dom4>cov.tresh]<-1

freq.1<-list()
freq.2<-list()
freq.3<-list()
freq.4<-list()

for(i in 1:ncol(spe.bb)){
freq.1[length(freq.1)+1]<-(sum(spe.dom1[i,])*100)/20
freq.2[length(freq.2)+1]<-(sum(spe.dom2[i,])*100)/20
freq.3[length(freq.3)+1]<-(sum(spe.dom3[i,])*100)/20
freq.4[length(freq.4)+1]<-(sum(spe.dom4[i,])*100)/20
}
dominant2<-data.frame(sp=as.character(row.names(spe.t1)), fr1=as.numeric(freq.1), fr2=as.numeric(freq.2),
                      fr3=as.numeric(freq.3), fr4=as.numeric(freq.4))

dom2.sp1<-dominant2[which(dominant2$fr1>freq.tresh),1]
dom2.sp2<-dominant2[which(dominant2$fr2>freq.tresh),1]
dom2.sp3<-dominant2[which(dominant2$fr3>freq.tresh),1]
dom2.sp4<-dominant2[which(dominant2$fr4>freq.tresh),1]

dom2.sp1
dom2.sp2
dom2.sp3
dom2.sp4

# NMDS plot with dominan species
data.scores <- as.data.frame(scores(NMDS))  #Using the scores function from vegan to extract the site scores and convert to a data.frame
data.scores$site <- rownames(data.scores)  # create a column of site names, from the rownames of data.scores
data.scores$gr <- dat$gr  #  add the grp variable created earlier

sp.dom<-unique(c(dom2.sp1, dom2.sp2, dom2.sp3, dom2.sp4))
species.scores.dom<-species.scores[sp.dom,]

#### Indicator species analyses
#### List of significant species for each vegetation belt

indval = multipatt(spe.bb, gr2, duleg = TRUE, control = how(nperm=999), func = "IndVal.g")
summary(indval, indvalcomp=TRUE)
summary(indval)

# Indicator Species with pvalues = 0.001
indval$sign[which(indval$sign[,1]==1 & indval$sign[,7]==0.001),]
indval$sign[which(indval$sign[,2]==1 & indval$sign[,7]==0.001),]
indval$sign[which(indval$sign[,3]==1 & indval$sign[,7]==0.001),]
indval$sign[which(indval$sign[,4]==1 & indval$sign[,7]==0.001),]



####################### STEP 5
####################### Land-cover and vegetation changes


#### Trends of changes
#### Local polynomial regression of membership values sums for each time window

years<-c("XX", "YY")

fz.area.6cl<- data.frame(year=years, water=0, ice=0, subnival=0, UAgrass=0, LAgrass=0, forest=0)

fz.area.6cl$water<-c((sum(df.fuzzy.indXX.6[,6])*(30*30))/10000, (sum(df.fuzzy.indYY.6[,6])*(30*30))/10000)
fz.area.6cl$ice<-c((sum(df.fuzzy.indXX.6[,5])*(30*30))/10000, (sum(df.fuzzy.indYY.6[,5])*(30*30))/10000)
fz.area.6cl$subnival<-c((sum(df.fuzzy.indXX.6[,4])*(30*30))/10000, (sum(df.fuzzy.indYY.6[,4])*(30*30))/10000)
fz.area.6cl$UAgrass<-c((sum(df.fuzzy.indXX.6[,3])*(30*30))/10000, (sum(df.fuzzy.indYY.6[,3])*(30*30))/10000)
fz.area.6cl$LAgrass<-c((sum(df.fuzzy.indXX.6[,2])*(30*30))/10000, (sum(df.fuzzy.indYY.6[,2])*(30*30))/10000)
fz.area.6cl$forest<-c((sum(df.fuzzy.indXX.6[,1])*(30*30))/10000, (sum(df.fuzzy.indYY.6[,1])*(30*30))/10000)

lo.fz.water6 <- loess(fz.area.6cl$water~as.numeric(fz.area.6cl$year))
lo.fz.ice6 <- loess(fz.area.6cl$ice~as.numeric(fz.area.6cl$year))
lo.fz.subnival6 <- loess(fz.area.6cl$subnival~as.numeric(fz.area.6cl$year))
lo.fz.UPgrass6 <- loess(fz.area.6cl$UAgrass~as.numeric(fz.area.6cl$year))
lo.fz.LAgrass6 <- loess(fz.area.6cl$LAgrass~as.numeric(fz.area.6cl$year))
lo.fz.forest6 <- loess(fz.area.6cl$forest~as.numeric(fz.area.6cl$year))
min(fz.area.6cl[,2:6])
max(fz.area.6cl[,2:6])

### Trend dataset
trend<-data.frame(Types=c(rep("Forest",11),rep("LA grassland",11), rep("UA grassland",11),
                            rep("Subnival",11),rep("Glacier",11),rep("Water",11)),
                  Year=c(rep(years,6)),
                  Point=c(fz.area.6cl$forest, fz.area.6cl$LAgrass, fz.area.6cl$UAgrass,
                          fz.area.6cl$subnival, fz.area.6cl$ice, fz.area.6cl$water),
                   Loess=c(predict(lo.fz.forest6),predict(lo.fz.LAgrass6),predict(lo.fz.UAgrass6),
                            predict(lo.fz.subnival6),predict(lo.fz.ice6),predict(lo.fz.water6)),
                   Types2=c(rep("Vegetated land-cover types", 11*3),rep("Virtually unvegetated land-cover types",11*3)))
trend$Types<-factor(trend$Types, unique(trend$Types))
trend$Types2<-factor(trend$Types2, unique(trend$Types2))

# GGplot for trends

col_magni<-c("green4","goldenrod3","orangered3","grey60","cyan3","blue4")

t_tot<-ggplot(data=trend, aes(x=Year, y=Point, group=Types, colour=Types)) +
    geom_point(size=2) +
    geom_smooth (method="loess", aes(fill=Types))+
    coord_cartesian(ylim=c(250, 5500)) +
    theme(axis.text.x = element_text(angle = 90)) +
    labs(colour="Land-cover types") + 
    scale_y_continuous(name="Surface (ha)") +
    scale_colour_manual(values = c(col_magni)) +
    scale_fill_manual(values = c(col_magni)) +
    facet_wrap(~Types2)


#### Magnitude of changes
#### Differences between membership values sums of latest and earliest time windows

(fz.area.6cl$ice[11]-fz.area.6cl$ice[1])
((fz.area.6cl$ice[11]-fz.area.6cl$ice[1])*100)/(fz.area.6cl$ice[1])

(fz.area.6cl$subnival[11]-fz.area.6cl$subnival[1])
((fz.area.6cl$subnival[11]-fz.area.6cl$subnival[1])*100)/(fz.area.6cl$subnival[1])

(fz.area.6cl$forest[11]-fz.area.6cl$forest[1])
((fz.area.6cl$forest[11]-fz.area.6cl$forest[1])*100)/(fz.area.6cl$forest[1])

(fz.area.6cl$LAgrass[11]-fz.area.6cl$LAgrass[1])
((fz.area.6cl$LAgrass[11]-fz.area.6cl$LAgrass[1])*100)/(fz.area.6cl$LAgrass[1])

(fz.area.6cl$UAgrass[11]-fz.area.6cl$UAgrass[1])
((fz.area.6cl$UAgrass[11]-fz.area.6cl$UAgrass[1])*100)/(fz.area.6cl$UAgrass[1])

magnitude<-data.frame(
Types=c("Forest","LA grassland","UA grassland","Subnival", "Glacier", "Water"),
Hectars=c(fz.area.6cl$forest[11]-fz.area.6cl$forest[1],fz.area.6cl$LAgrass[11]-fz.area.6cl$LAgrass[1],fz.area.6cl$UAgrass[11]-fz.area.6cl$UAgrass[1],
fz.area.6cl$subnival[11]-fz.area.6cl$subnival[1],fz.area.6cl$ice[11]-fz.area.6cl$ice[1],fz.area.6cl$water[11]-fz.area.6cl$water[1]),
Percentage=c(
((fz.area.6cl$forest[11]-fz.area.6cl$forest[1])*100)/(fz.area.6cl$forest[1]),
((fz.area.6cl$shrub[11]-fz.area.6cl$LAgrass[1])*100)/(fz.area.6cl$LAgrass[1]),
((fz.area.6cl$grass[11]-fz.area.6cl$UAgrass[1])*100)/(fz.area.6cl$UAgrass[1]),
((fz.area.6cl$subnival[11]-fz.area.6cl$subnival[1])*100)/(fz.area.6cl$subnival[1]),
((fz.area.6cl$ice[11]-fz.area.6cl$ice[1])*100)/(fz.area.6cl$ice[1]),
((fz.area.6cl$water[11]-fz.area.6cl$water[1])*100)/(fz.area.6cl$water[1])
))

magnitude$Hectars<-round(magnitude$Hectars,1)
magnitude$Percentage<-round(magnitude$Percentage,1)

magnitude$Labels_ha<-c("Forest: 862 ha", "LA grassland: -40 ha",
                        "UA grassland: -480 ha", "Subnival: 336 ha",
                        "Glacier: -774 ha", "Water: 96 ha")
magnitude$Labels_per<-c("Forest: 24 %", "LA grassland: -0.9 %",
                        "UA grassland: -10 %", "Subnival: 8 %",
                        "Glacier: -23 %", "Water: 11 %")
magnitude$Trend<-c("Increasing","Decreasing","Decreasing","Increasing","Decreasing", "Increasing")
magnitude[,2:3]<-abs(magnitude[,2:3])

# Treemaps for magnitude of changes

magnitude$Trend <- factor(magnitude$Trend, levels=unique(magnitude$Trend))


tm_ha<-ggplot(magnitude, aes(area =Hectars, fill = Types, label = Labels_ha,
                subgroup = Trend)) +
                geom_treemap(color="white", size=3) +
                geom_treemap_text(place="topleft",grow=T, ,min.size = 0, 
                                 angle=c(0,90,0,0,0,90), color="white")+
                geom_treemap_subgroup_border(colour="black", size=5) +
                geom_treemap_subgroup_text(place = "bottom", size = 30, colour =
                             "black", fontface = "italic", min.size = 0, padding.y = grid::unit(3, "mm")) +
                scale_fill_manual(values = col_magni) + 
                labs("Land-cover \ntypes")

tm_ha<-tm_ha + guides(fill=guide_legend(title="Land-cover \ntypes"))
tm_per<-ggplot(magnitude, aes(area =Percentage, fill = Types, label = Labels_per,
                subgroup = Trend)) +
                geom_treemap(color="white", size=3) +
                geom_treemap_text(place="topleft", grow = T, min.size = 0, 
                                  angle=c(0,90,0,0,0,0), color="white") +
                geom_treemap_subgroup_border(colour="black", size=5) +
                geom_treemap_subgroup_text(place = "bottom", size=30, colour =
                             "black", fontface = "italic", min.size = 0,padding.y = grid::unit(3, "mm")) +
                scale_fill_manual(values = col_magni)

prow <- plot_grid( tm_ha + theme(legend.position="none"),
           tm_per + theme(legend.position="none"),
           align = 'vh',
           labels = c("a)", "b)"),
           nrow = 2,
  hjust = -0.1,
  vjust = 1.5,
scale=0.95
           )
prow



#### Elevational shift
#### T-test between occupied elevations of ealriest and latest time window


# Obtain DEM at 30 m of resolution from a DEM at 25 m
dem25<-crop(raster("C:/path/.../Dem25.tif"), area)

dem25<-mask(crop(dem25, area), area)
dem30<-resample(dem25, dnXX[[1]], method="bilinear")
dem30<-mask(dem30, mask.buffer.pol, inverse=TRUE)
df.dem30<-as.data.frame(dem30, na.rm=TRUE, xy=TRUE)

# Dataset: Altitude of occupied surfaces by 6 land-cover types

# Check the number of altitude breaks based on the altitudinal range 
# wanted for the analysis (i.e. 20 m)
(max(df.dem30$dem)-min(df.dem30$dem))/20
# Add the col counts (all 1) to make possible the calculation of total 
# surfaces within altitudinal ranges 
df.dem30$counts<-c(1)

# Create the altitude breaks limits based in the final number of breaks (i.e. 115)
alt.breaks <- levels(cut(df.dem30$dem, breaks = 115))
alt.breaks<-as.data.frame(cbind(lower = as.numeric( sub("\\((.+),.*", "\\1", alt.breaks) ),
      upper = as.numeric( sub("[^,]*,([^]]*)\\]", "\\1", alt.breaks) )))

#Calculate total surfaces within altitudinal ranges 
sum.dem <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(df.dem30$counts[ df.dem30$dem >= x[1] & df.dem30$dem < x[2] ]) })

# Prepare the dataset that will be reduced due to NA values in DEM raster
# Classes: 1-Forest, 2-LA grassland, 3-UA grassland, 4-Subnival, 5-Glacier, 6-Water bodies

df.fzXX.6<-as.data.frame(brick(stack(ras.fz.indXX.6, dem30)), na.rm=TRUE, xy=TRUE)
df.fzXX.6$row.names<-c(row.names(df.fzXX.6))
clusters_dem<-clusters
clusters_dem$row.names<-c(row.names(clusters_dem))
clusters_dem<-clusters_dem %>% inner_join(df.fzXX.6)

df.fzYY.6<-as.data.frame(brick(stack(ras.fz.indYY.6, dem30)), na.rm=TRUE, xy=TRUE)
df.fzYY.6$row<-c(row.names(df.fzYY.6))
clusters_dem<-clusters_dem %>% inner_join(df.fzYY.6)

# Calculate total surfaces (fuzzy values as fraction of cover) within altitudinal ranges for different land-cover types and years

sum.iceXX.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_ice_XX[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })
sum.subnivalXX.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_subnival_XX[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })
sum.UAgrassXX.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_UAgrass_XX[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })
sum.LAgrassXX.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_LAgrass_XX[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })
sum.forestXX.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_forest_XX[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })

sum.iceYY.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_ice_YY[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })
sum.subnivalYY.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_subnival_YY[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })
sum.UAgrassYY.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_UAgrass_YY[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })
sum.LAgrassYY.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_LAgrass_YY[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })
sum.forestYY.6 <- apply(alt.breaks, MARGIN=1, FUN=function(x) { sum(clusters_dem$fz_forest_YY[ clusters_dem$dem30 >= x[1] & clusters_dem$dem30 < x[2] ]) })


# Organize the dataset for altitude

Type_yr<-c(rep("Study area",115),rep("Forest '87", 115), rep("Forest '16", 115),
            rep("LA grassland '87", 115), rep("LA grassland '16", 115),
             rep("UA grassland '87", 115), rep("UA grassland '16", 115),
             rep("Bare soil '87", 115), rep("Bare soil '16", 115),
             rep("Glacier '87", 115), rep("Glacier '16", 115))

alt.breaks$mean<-alt.breaks$lower+((alt.breaks$upper-alt.breaks$lower)/2)

Area_df<-data.frame(Types=Type_yr, Area=c(sum.dem, sum.forestXX.6, sum.forestYY.6,
				                   sum.LAgrassXX.6, sum.LAgrassYY.6, sum.UAgrassXX.6, sum.UAgrassYY.6,
				                   sum.subnivalXX.6, sum.subnivaYY.6, sum.iceXX.6, sum.iceYY.6),
				breaks=c(rep(alt.breaks$mean, 11)),
                        Lty=c(rep("solid",115),rep("dashed",115),rep("solid",115),
                              rep("dashed",115),rep("solid",115),rep("dashed",115),
                              rep("solid",115),rep("dashed",115),rep("solid",115),
                              rep("dashed",115),rep("solid",115)))

Area_df$Types<-factor(Area_df$Types,unique(Area_df$Types))
Area_df$Lty<-factor(Area_df$Lty,unique(Area_df$Lty))

# GGplot for altitude and associated indicator species

col_alt<-c("red","green4","green4","goldenrod3","goldenrod3","orangered3","orangered3",
"grey60","grey60","cyan3","cyan3","blue4","blue4")

p<-ggplot(data=Area_df, aes(x=breaks, y=Area, group=Types, color=Types)) +
      geom_line(aes(linetype=Lty),size=1.2) +
      scale_colour_manual(values = c(col_alt))
p+theme_bw() + scale_y_continuous(name="Surface (ha)")

col_magni<-c("green4","goldenrod3","orangered3","grey60")


unique(alt.ind$sp)
rl<-ggplot(alt.ind, aes(x = alt, y = sp, fill = label)) +
  geom_density_ridges(alpha = 0.3,scale = 2) +
  theme_ridges(center_axis_labels = TRUE) + 
  scale_fill_manual(values=c(col_magni)) +
  theme()
IndSpe_graph<-rl + labs(x="Elevation (m a.s.l.)", y="Indicator species",
           fill = "Land-cover types", size=0.1) + 
  scale_x_continuous(expand = c(0, 0)) +
  scale_y_discrete(expand = c(0, 0)) +
  coord_cartesian(clip = "off")


# t-test for hard classified land cover types

alt.for.XX<-clusters_dem[which(clusters_dem$fz_forest_XX>=0.5),18]
alt.for.YY<-clusters_dem[which(clusters_dem$fz_forest_YY>=0.5),18]

alt.LAgrass.XX<-clusters_dem[which(clusters_dem$fz_LAgrass_XX>=0.5),18]
alt.LAgrass.YY<-clusters_dem[which(clusters_dem$fz_LAgrass_YY>=0.5),18]

alt.UAgrass.XX<-clusters_dem[which(clusters_dem$fz_UAgrass_XX>=0.5),18]
alt.UAgrass.YY<-clusters_dem[which(clusters_dem$fz_UAgrass_YY>=0.5),18]

alt.subnival.XX<-clusters_dem[which(clusters_dem$fz_subnival_XX>=0.5),18]
alt.subnival.YY<-clusters_dem[which(clusters_dem$fz_subnival_YY>=0.5),18]

alt.glacier.XX<-clusters_dem[which(clusters_dem$fz_glacier_XX>=0.5),18]
alt.glacier.YY<-clusters_dem[which(clusters_dem$fz_glacier_YY>=0.5),18]

# check for normal distribution
par(mfrow=c(1,2))
hist(alt.for.XX); hist(alt.for.YY)
par(mfrow=c(1,2))
hist(alt.LAgrass.XX); hist(alt.LAgrass.YY)
par(mfrow=c(1,2))
hist(alt.UAgrass.XX); hist(alt.UAgrass.YY)
par(mfrow=c(1,2))
hist(alt.subnival.XX); hist(alt.subnival.YY)
par(mfrow=c(1,2))
hist(alt.glacier.XX); hist(alt.glacier.YY)

t.for<-t.test(alt.for.XX,alt.for.YY)
t.LAgrass<-t.test(alt.LAgrass.XX,alt.LAgrass.YY)
t.UAgrass<-t.test(alt.UAgrass.XX,alt.UAgrass.YY)
t.subnival<-t.test(alt.subnival.XX,alt.subnival.YY)
t.glacier<-t.test(alt.glacier.XX,alt.glacier.YY)

wilcox.test(alt.for.87, alt.for.16, alternative = "two.sided")
wilcox.test(alt.LAgrass.XX,alt.LAgrass.YY, alternative = "two.sided")
wilcox.test(alt.UAgrass.XX,alt.UAgrass.YY, alternative = "two.sided")
wilcox.test(alt.subnival.XX,alt.subnival.YY, alternative = "two.sided")
wilcox.test(alt.glacier.XX,alt.glacier.YY, alternative = "two.sided")









